==> haskell-tidal-link-1.0.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tidal-link.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tidal-link
version:              1.0.1
visibility:           public
id:                   tidal-link-1.0.1-11erSVDHID8JnduY8ph7Ga
key:                  tidal-link-1.0.1-11erSVDHID8JnduY8ph7Ga
license:              GPL-3.0-only
copyright:            (c) Pierre Krafft and contributors, 2021
maintainer:
    Pierre Krafft <kpierre@outlook.com>, Alex McLean <alex@slab.org>

author:               Pierre Krafft
stability:            Experimental
homepage:             http://tidalcycles.org/
synopsis:             Ableton Link integration for Tidal
description:
    Ableton Link integration for Tidal, to let Tidal sync with external clocks

category:             Sound
abi:                  2380c66d7282cb21bf0f3ab257233367
exposed:              True
exposed-modules:      Sound.Tidal.Link
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tidal-link-1.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tidal-link-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tidal-link
hs-libraries:         HStidal-link-1.0.1-11erSVDHID8JnduY8ph7Ga
extra-libraries:      stdc++
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-tidal-link/html/tidal-link.haddock
haddock-html:         /usr/share/doc/haskell-tidal-link/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tidal-link-1.0.3-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tidal-link.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tidal-link
version:              1.0.3
visibility:           public
id:                   tidal-link-1.0.3-I5U1Wc4P3k4JeOMqGuGeth
key:                  tidal-link-1.0.3-I5U1Wc4P3k4JeOMqGuGeth
license:              GPL-3.0-only
copyright:            (c) Pierre Krafft and contributors, 2021
maintainer:
    Pierre Krafft <kpierre@outlook.com>, Alex McLean <alex@slab.org>

author:               Pierre Krafft
stability:            Experimental
homepage:             http://tidalcycles.org/
synopsis:             Ableton Link integration for Tidal
description:
    Ableton Link integration for Tidal, to let Tidal sync with external clocks

category:             Sound
abi:                  fb37f6583d4ed334c2f5a66543ac31dc
exposed:              True
exposed-modules:      Sound.Tidal.Link
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tidal-link-1.0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tidal-link-1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tidal-link
hs-libraries:         HStidal-link-1.0.3-I5U1Wc4P3k4JeOMqGuGeth
extra-libraries:      stdc++
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-tidal-link/html/tidal-link.haddock
haddock-html:         /usr/share/doc/haskell-tidal-link/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
